#
# spec file for package grisbi
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           grisbi
Version:        3.0.4
Release:        1.3
Summary:        Personal Accounting Application
License:        GPL-2.0-or-later
Group:          Productivity/Office/Finance
URL:            http://www.grisbi.org
Source0:        https://downloads.sourceforge.net/project/grisbi/grisbi%20stable/3.0.x/%{version}/%{name}-%{version}.tar.bz2
Source1:        https://downloads.sourceforge.net/project/grisbi/grisbi%20stable/3.0.x/%{version}/%{name}-%{version}.tar.bz2.asc

BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0) >= 2.56
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24
BuildRequires:  pkgconfig(libcrypto) >= 1.0.0
BuildRequires:  pkgconfig(libgoffice-0.10) >= 0.10.0
BuildRequires:  pkgconfig(libgsf-1) >= 1.14
BuildRequires:  pkgconfig(libofx) >= 0.9
BuildRequires:  pkgconfig(libssl) >= 1.0.0
BuildRequires:  pkgconfig(libxml-2.0) >= 2.5.0
BuildRequires:  pkgconfig(zlib)
ExcludeArch:    %{ix86}

%description
Grisbi is a personal accounting application, aiming at providing the most
simple and intuitive software for basic use, although it can be very powerful
if you spend a little time on the setup.

One notable feature is that it respects French accounting rules.

%lang_package

%prep
%autosetup -p1

%build
%configure \
	--disable-static \
	--disable-schemas-compile \
	%{nil}
%make_build

%install
%make_install

# Those files are deprecated and not needed anymore
rm %{buildroot}%{_datadir}/mime-info/grisbi.{keys,mime}

%find_lang %{name} %{?no_lang_C}
%fdupes -s %{buildroot}%{_datadir}

%check
%make_build check

%files
%license COPYING
%doc AUTHORS NEWS README
%{_bindir}/grisbi
%{_mandir}/man1/grisbi.1%{?ext_man}
%{_datadir}/applications/org.grisbi.Grisbi.desktop
%{_datadir}/doc/grisbi/
%{_datadir}/grisbi/
%{_datadir}/icons/*/*/*/*grisbi.*
%{_datadir}/mime/packages/grisbi.xml
%{_datadir}/pixmaps/grisbi/
%{_datadir}/metainfo/%{name}.metainfo.xml

%files lang -f %{name}.lang

%changelog
* Sat Jan 25 2025 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 3.0.4:
  + Bug fixes
- Changes from version 3.0.3:
  + Bug fixes
- Changes from version 3.0.2:
  + Bug fixes
  + Do not use intltool to build Grisbi
- Changes from version version 3.0.1:
  + Bug fixes
- Changes from version 3.0.0:
  + Changing the payee search
  + Adding new type of consumer loan
  + Adding the all transactions in archive when the account is closed
  + Bug fixes
  + Code cleanup
  + Preparing for the transition to gtk4
* Wed Mar 13 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Move install commands into %%install section
* Fri Nov 10 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add ix86 ExcludeArch: goffice is no longer built for that target.
* Wed Dec 15 2021 Michael Gorse <mgorse@suse.com>
- Update to version 2.0.5:
  + Bug fixes.
* Wed Apr 14 2021 Ailin Nemui <ailin.nemui@gmail.com>
- Update to version 2.0.3:
  + Automatic integration of dark themes
  + New color management of grisbi
  + Added the ability to change the font size globally
  + Improved use of grisbi with low definition screens
  + Redesign of the credit management module
  + Added import rules for CSV files
  + Added of a search module in the list of operations
  + Added the ability to automatically delete old backups
  + Bugs fix
* Thu Jan 30 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.2.2:
  + Bug fixes.
- Changes from version 1.2.1:
  + Bug fixes.
- Changes from version 1.2.0:
  + Added rules for importing CSV files.
  + Addition of new rules for payees management.
  + Added automatic creation of vented transactions for loan
    maturities.
  + Various improvements for preferences and reports.
  + Bug fixes.
- Drop obsolete post(un) scriptlets.
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Thu Jun 14 2018 luc14n0@linuxmail.org
- Add conditionalized post(un) scriptlets to run desktop_database,
  icon_theme_cache and mime_database for suse_version < 1330.
* Wed Jun 13 2018 bjorn.lie@gmail.com
- Update to version 1.1.93:
  + Fix a crash.
  + Port to Gtk 3.
  + Updated translations.
* Tue Jun 12 2018 bjorn.lie@gmail.com
- Disable optional pkgconfig(libgoffice-0.8) BuildRequires, we do
  not want to depend on this compat package anymore.
- Enable cunit-devel BuildRequires and make check, run tests.
- Run spec-cleaner.
* Mon Jun  4 2018 bjorn.lie@gmail.com
- Update to version 1.0.4:
  + Fix a bug when the scheduled transaction is executed
    automatically once.
  + Fix bugsreports link.
  + Adding a new option for futures dates.
- Changes from version 1.0.3:
  + Fix display bug of bet_tab when load a new account file.
  + Fix bug in forecasts when decimal_point is comma "," and
    thousands_separator is dot ".".
  + Fix display split transactions in budgetary lines view.
  + Partial correction of bug "creating duplicate transactions when
    categories are not used".
  + Fix warning when date is NULL in bet_tab.c.
  + Fix a warning when displaying reconciled transactions.
  + Added all scheduled transactions of the month if
    conf.execute_scheduled_of_month = TRUE.
  + Fix display bug of the last scheduled transaction of the
    period.
- Drop libofx-devel BuildRequires, already in place as pkgconfig().
- Do minor spec-cleaning.
* Sat Sep  9 2017 zaitor@opensuse.org
- Update to version 1.0.2:
  + Add Cuban Convertible Peso currency.
  + Fix bug when creating and removing a report in gtk_combofix.c.
  + Fix bug of test date for a transaction in bet_transfert.
  + Fix a bug when importing a category without sub-category.
  + Fix a bug of calculation of the balance of cash account.
  + Adding the descending sort of dates for the reconciliations.
  + Fix truncated month name for certain locales.
  + Fix a bug of update of main account if more deferred debit
    accounts.
* Thu Nov  3 2016 dimstar@opensuse.org
- Update to version 1.0.1:
  + Fix major crash with gtk-2.24.30.
  + Fix many other bugs.
  + Fix many memory leaks.
  + Initialization of the financial year when creating a new
    archive.
  + Allow editing the 'voucher field' of the child transaction.
  + Homogenization of code to categories and budgetary allocations.
* Sat Aug  9 2014 dimstar@opensuse.org
- Update to version 1.0.0:
  + Chart on budget estimates.
  + Bankcard management with estimates.
  + Accountancy adapted to associations.
  + More contextual menus.
  + Adding of goffice's library for the graphs.
  + Import of categories files in budgetary lines.
  + Change the accounts list order by drag and drop.
  + Balance in function of operation date or its value date.
  + Display of unused payees.
  + Full screen display through F11 function key.
  + New operation through <Ctrl><T> keyboard shortcut.
  + User manual direct access through Help menu or <Ctrl><H>
    keyboard shortcut.
  + new french user manual.
  + fixes many bugs.
  + fix many memory leaks.
- Add pkgconfig(libgoffice-0.8) and pkgconfig(libofx)
  BuildRequires: new dependencies.
* Wed Jan  4 2012 vuntz@opensuse.org
- Update to version 0.8.9:
  + Fix a potential crash when closing Grisbi.
  + Fix --without-ofx configure option.
  + Minor changes.
- Drop grisbi-fix-linking.patch: fixed upstream.
- Remove call to autoreconf and libtool BuildRequires: they were
  only needed for the patch above.
- Stop passing --with-ofx to configure as... this breaks the build
  for ofx support. We use automatic detection now, and the build
  will fail if ofx support is missing as the plugin listed in
  %%files will be missing.
* Sat Oct 15 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Mon Sep 19 2011 vuntz@opensuse.org
- Update to version 0.8.8:
  + Fix bug where the transaction is not transferred to the new
    account when Edit menu is used
  + Fix the name of the International Russian currency RUB -> RUR
  + Fix some bugs in the navigation in the left panel
  + Fix a crash when the number of recently used files = 0
  + Remove the display of the build date for stable versions
- Drop grisbi-no_date_time.patch: fixed upstream.
- Add grisbi-fix-linking.patch: fix build with strict linker, as in
  Factory.
- Add call to autoreconf, needed for above patch.
* Tue Jun  7 2011 dimstar@opensuse.org
- Update to version 0.8.7:
  + Fix a problem of gtk version under Windows.
- Add grisbi-no_date_time.patch: Do not add build date and time to
  binaries.
* Mon May 23 2011 dimstar@opensuse.org
- Update to version 0.8.6:
  + Fix a problem of calculating the balance after deletion of two
    archives
  + Simplification of the function for parsing dates, fixing a
    crash on Windows
  + Add support for the variance for the planned transactions
  + Fix various bugs
* Tue May  3 2011 vuntz@opensuse.org
- Update to version 0.8.5:
  + Added cloning of scheduled operations
  + Fixed a bug of calculating balances with different currencies
    in the table estimates
  + Fixed a bug in creation of payees and creation of a
    sub-budgetary line
  + Don't update the tree view when it's not here while making an
    archive
  + Typo in function name. Don't repeat twice the same by Mokona
  + Fixed bug: Grisbi crashes when Importing a QIF file with a list
    of categories
  + Adding of Data_Path variable to debug
- Changes from version 0.8.4:
  + Fixes a bug that corrupts the file of accounts when saving in
    certain circumstances.
  + Minor corrections in the management of the logo of Grisbi
- Changes from version 0.8.3:
  + Fixed a bug export csv files on Windows
  + Fixed a potential crash
  + Fixed bug: The box of restoration of the sub-transactions
    appears again if the operation is no longer a split transaction
  + Adding the XDG directories in the printed variables and fix
    memory leaks
  + Fixed bug: Problem of updating of the pointing balance
  + Fixed a crash when importing a file without extension
  + Fixed bug: Filtering problem by amount
- Changes from version 0.8.2:
  + Fixed bug: Unable to delete third, category, or budget item
- Changes from version 0.8.1:
  + Fixed bug: Unable to enter a debit or credit
- Changes from version 0.8.0:
  + Integration of the budget module in the basic version of Grisbi
  + Integration of a simulator credits with the ability to print or
    export the data into a spreadsheet
  + Management of local settings (date format, decimal separator
    and thousands separator)
  + Addition of the amortization schedule for liability accounts
  + Addition of custom icons in the accounts file
  + Colorization of debits in the scheduler
  + Rewrite of gtk_combofix for payees to remove delays
  + Rewritten import of QIF files
  + Use gint64 to expand the fields of numbers up to 9 223 372 036
    854 775 807
  + Many bugs fixed
* Thu Apr 28 2011 vuntz@opensuse.org
- Cleanup for inclusion in Factory.
* Fri Apr  8 2011 cbosdonnat@novell.com
- Cleaned grisbi.spec file
* Tue Aug 31 2010 pascal.bleser@opensuse.org
- update to 0.6.0:
  * file encryption support
  * new and improved print system
    + LaTeX no more needed, printing has never been so straightforward
    + transaction list can be printed as well as reports
  * improved user interface
    + tabs deprecated in favor of a navigation tree
    + redesigned categories/payees/budgetary lines trees
    + totally redesigned transaction list with native GTK2 widgets
    + split of transactions displayed directly in transaction list
    + optional grid in transaction list
    + new "view" menu
    + use of assistants to ease some operations
    + custom sort for transaction list columns
    + reconcile now shows togglable buttons
    + use of + and - in amount entry to increment/decrement values
    + quick import of recurrent files
    + pre-built category sets dependent of the locale
    + all colors can be customized
    + astonishing icons ... can't ask for more!
  * Greek translation thanks to Achilleas
  * archival of old transactions, possibly into separate files
  * form structure defined by user
  * end of the obligation to use Euro
  * Gnucash and CSV files import
  * HBCI support through the aqbanking plugin
  * reconciled transactions are "archived" by default
  * huge work on localization :
    + Grisbi suggests a default currency according to the locale
    + dates are now displayed and parsed according to the locale, no more unbearable european dates for overseas folks!
    + amounts are displayed according to locale
  * it is now possible to omit decimal separator in numerical fields
  * custom mathematics engine that do not rely on float anymore
  * plugin system
  * new english file format
  * tool management for the payees
  * automatic association of third parties and categories for import files
  * ability to create a partial balance in the main view
* Sat Mar  8 2008 guru@unixtech.be
- moved to openSUSE Build Service
* Wed Jan  2 2008 guru@unixtech.be
- fixed prefix on 10.3
- rebuild against latest libofx
* Mon Oct  8 2007 guru@unixtech.be
- moved to Packman
- fixed build on openSUSE 10.3
* Fri Jul 21 2006 guru@unixtech.be
- new upstream version
* Thu Jun 22 2006 guru@unixtech.be
- pass -j flag to make
- added binary stripping on SUSE < 9.3
- removed Packager and Distribution, injected by rpmmacros
* Tue Dec 27 2005 guru@unixtech.be
- new upstream version
* Sun Oct 16 2005 guru@unixtech.be
- changed to configure macro
- added debuginfo support
* Sun Jun  5 2005 guru@unixtech.be
- added suse_update_config
- added suse_update_desktop_file
- version 0.5.7
* Thu Jan 13 2005 guru@unixtech.be
- version 0.5.5
* Thu Dec  2 2004 guru@unixtech.be
- version 0.5.3
* Wed Oct 20 2004 guru@unixtech.be
- now uses libofx shipped with SUSE on 9.1 and my very own libofx packages for SUSE <= 9.0
- added desktop file
- switched to find_lang
- forced use of libofx at ./configure
- changed release tag to include .guru.
- revamped the spec file a little
- version 0.5.2
* Mon Aug  2 2004 guru@unixtech.be
- added libofx support
- version 0.5.1
* Thu Jun 17 2004 guru@unixtech.be
- version 0.5.0
* Sun Jan  4 2004 guru@unixtech.be
- added untested support for Redhat and Mandrake
- french translation
- first RPM for SUSE
